..
  Copyright (C) 2025 Andrea Raffo <andrea.raffo@ibv.uio.no>
  SPDX-License-Identifier: MIT

Introduction
============

StripePy is a CLI application written in Python that recognizes architectural stripes found in the interaction matrix files generated by Chromosome Conformation Capture experiments, such as Hi-C and Micro-C.

.. only:: not latex

  Documentation formats
  ---------------------

  You are reading the HTML version of the documentation. An alternative `PDF
  version <https://stripepy.readthedocs.io/_/downloads/en/stable/pdf/>`_ is
  also available.

  Installation
  ------------

.. only:: latex

  Documentation formats
  ---------------------

  You are reading the PDF version of the documentation.

  The live HTML version of the documentation is available at `<https://stripepy.readthedocs.io/en/stable/>`_.

  .. rubric:: Installation

StripePy can be installed using pip or conda with e.g., ``pip install 'stripepy-hic[all]'``.
Refer to :doc:`Installation <./installation>` for more details.

.. only:: not latex

  How to cite this project?
  -------------------------

.. only:: latex

  .. rubric:: How to cite this project?

Please use the following BibTeX template to cite StripePy in scientific
discourse:

.. code-block:: bibtex

  @article{stripepy,
    author = {Raffo, Andrea and Rossini, Roberto and Paulsen, Jonas},
    title = {{StripePy: fast and robust characterization of architectural stripes}},
    journal = {Bioinformatics},
    volume = {41},
    number = {6},
    pages = {btaf351},
    year = {2025},
    month = {06},
    issn = {1367-4811},
    doi = {10.1093/bioinformatics/btaf351},
    url = {https://doi.org/10.1093/bioinformatics/btaf351},
    eprint = {https://academic.oup.com/bioinformatics/article-pdf/41/6/btaf351/63484367/btaf351.pdf},
  }

.. only:: not latex

  Table of contents
  -----------------

.. toctree::
  :caption: Installation
  :maxdepth: 1

  installation

.. toctree::
  :caption: Getting started
  :maxdepth: 1

  quickstart
  downloading_sample_datasets
  detect_stripes
  fetch_stripes
  generate_plots

.. toctree::
  :caption: CLI and API Reference
  :maxdepth: 1

  cli_reference
  api

.. toctree::
   :caption: Telemetry
   :maxdepth: 1

   telemetry
